@@ -1,16 +1,23 @@
-from django.conf import settings
-from django.contrib import admin
-from django.contrib.admin.util import unquote
-from django.contrib.admin.views.main import ChangeList
+from functools import update_wrapper
+
+# from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
-from functools import update_wrapper
-from django.utils.html import strip_spaces_between_tags as short
+# from django.utils.html import strip_spaces_between_tags as short
 from django.utils.translation import ugettext_lazy as _
+from django.template.loader import render_to_string
+from django.contrib import admin
+from django.contrib.admin.util import unquote
+from django.contrib.admin.views.main import ChangeList
 
 
 class OrderedModelAdmin(admin.ModelAdmin):
+
+    def get_model_info(self):
+        return dict(app=self.model._meta.app_label,
+                    model=self.model._meta.module_name)
+
     def get_urls(self):
         from django.conf.urls import patterns, url
 
@@ -18,25 +25,23 @@ class OrderedModelAdmin(admin.ModelAdmin):
             def wrapper(*args, **kwargs):
                 return self.admin_site.admin_view(view)(*args, **kwargs)
             return update_wrapper(wrapper, view)
-        info = self.model._meta.app_label, self.model._meta.module_name
         return patterns('',
-            url(r'^(.+)/move-(up)/$',
-                wrap(self.move_view),
-                name='%s_%s_move_up' % info),
-            url(r'^(.+)/move-(down)/$',
-                wrap(self.move_view),
-                name='%s_%s_move_down' % info),
-        ) + super(OrderedModelAdmin, self).get_urls()
+                        url(r'^(.+)/move-(up)/$', wrap(self.move_view),
+                            name='{app}_{model}_order_up'.format(**self.get_model_info())),
+
+                        url(r'^(.+)/move-(down)/$', wrap(self.move_view),
+                            name='{app}_{model}_order_down'.format(**self.get_model_info())),
+                        ) + super(OrderedModelAdmin, self).get_urls()
 
     def _get_changelist(self, request):
         list_display = self.get_list_display(request)
         list_display_links = self.get_list_display_links(request, list_display)
 
         cl = ChangeList(request, self.model, list_display,
-            list_display_links, self.list_filter, self.date_hierarchy,
-            self.search_fields, self.list_select_related,
-            self.list_per_page, self.list_max_show_all, self.list_editable,
-            self)
+                        list_display_links, self.list_filter, self.date_hierarchy,
+                        self.search_fields, self.list_select_related,
+                        self.list_per_page, self.list_max_show_all, self.list_editable,
+                        self)
 
         return cl
 
@@ -57,20 +62,15 @@ class OrderedModelAdmin(admin.ModelAdmin):
         return HttpResponseRedirect('../../%s' % self.request_query_string)
 
     def move_up_down_links(self, obj):
-        link_html = short("""
-            <a href="../../%(app_label)s/%(module_name)s/%(object_id)s/move-up/%(query_string)s">
-                <img src="%(STATIC_URL)sordered_model/arrow-up.gif" alt="Move up" />
-            </a>
-            <a href="../../%(app_label)s/%(module_name)s/%(object_id)s/move-down/%(query_string)s">
-                <img src="%(STATIC_URL)sordered_model/arrow-down.gif" alt="Move down" />
-            </a>""")
-
-        return link_html % {
+        return render_to_string("ordered_model/admin/order_controls.html", {
             'app_label': self.model._meta.app_label,
             'module_name': self.model._meta.module_name,
             'object_id': obj.id,
-            'STATIC_URL': settings.STATIC_URL,
+            'urls': {
+                'up': reverse("admin:{app}_{model}_order_up".format(**self.get_model_info()), args=[obj.id, 'up']),
+                'down': reverse("admin:{app}_{model}_order_down".format(**self.get_model_info()), args=[obj.id, 'down']),
+            },
             'query_string': self.request_query_string
-        }
+        })
     move_up_down_links.allow_tags = True
     move_up_down_links.short_description = _(u'Move')
